unit MainUnit;

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, FileUtil, LResources, Forms, Controls, Graphics, Dialogs,
  synaser, StdCtrls, ExtCtrls, IniFiles;

type

  { TForm1 }

  TForm1 = class(TForm)
    ButtonClose: TButton;
    CheckBoxCRLF: TCheckBox;
    ComboBoxBauds: TComboBox;
    ComboBoxPort: TComboBox;
    Image_rt: TImage;
    Image_gn: TImage;
    Label1: TLabel;
    Label2: TLabel;
    Label3: TLabel;
    Panel1: TPanel;
    Panel2: TPanel;
    Terminal: TMemo;
    Timer1: TTimer;
    SendString: TEdit;
    SendButton: TButton;
    ConnectButton: TButton;
    procedure ButtonCloseClick(Sender: TObject);
    procedure CheckBoxCRLFChange(Sender: TObject);
    procedure ConnectButtonClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure SendButtonClick(Sender: TObject);
    procedure Timer1Timer(Sender: TObject);
  private
    { private declarations }
    PortConnected : Boolean;
    FIni:TMemIniFile;
    mit_CRLF : Boolean;
  public
    { public declarations }
  end; 

var
  Form1: TForm1;
  PortCom: TBlockSerial;
  TimeOut: integer;

const ligneMax = 30;

implementation

{ TForm1 }




procedure TForm1.FormCreate(Sender: TObject);
var
  l, Com_Port : string;
  p, Zeiger, Baud_Rate: integer;
begin
  FIni := TMemIniFile.Create( ExtractFilePath(Application.ExeName)+'SETERM.ini');
  Com_Port := FIni.ReadString('ComPort', 'ComPort', 'COM1');
  Baud_Rate := FIni.ReadInteger('ComPort', 'BaudRate', 0);
  mit_CRLF := FIni.ReadBool('ComPort', 'mit_CRLF', false);

  Timer1.Enabled := false;
  Terminal.Clear;

  l := GetSerialPortNames;

  if l >'' then
    repeat begin
      p :=  pos(',',l);
      if p > 0 then begin
        ComboBoxPort.Items.Add(copy(L,1,p-1));
        delete(L,1,p);
      end
      else
        ComboBoxPort.Items.Add(L);
    end;
    until p = 0;

  Zeiger:=-1;
  for p:=0 to ComboBoxPort.Items.Count-1 do begin
    if ComboBoxPort.Items[p]=Com_Port then
      Zeiger:=p;

  end; { for p:=0 to ComboBoxPort.Items.Count-1 do }

  if Zeiger>-1 then
    ComboBoxPort.ItemIndex:=Zeiger
  else
    ComboBoxPort.ItemIndex:=0;


  ComboBoxBauds.Items.Add('   110');
  ComboBoxBauds.Items.Add('   300');
  ComboBoxBauds.Items.Add('   600');
  ComboBoxBauds.Items.Add('  1200');
  ComboBoxBauds.Items.Add('  2400');
  ComboBoxBauds.Items.Add('  4800');
  ComboBoxBauds.Items.Add('  9600');
  ComboBoxBauds.Items.Add(' 14400');
  ComboBoxBauds.Items.Add(' 19200');
  ComboBoxBauds.Items.Add(' 38400');
  ComboBoxBauds.Items.Add(' 56000');
  ComboBoxBauds.Items.Add(' 57600');
  ComboBoxBauds.Items.Add('115200');
  ComboBoxBauds.Items.Add('128000');
  ComboBoxBauds.Items.Add('256000');
  ComboBoxBauds.ItemIndex:=Baud_Rate;


  ConnectButton.Caption:='Verbinden';
  PortConnected:=false;

  Image_rt.Visible:=true;
  Image_gn.Visible:=false;


  if mit_CRLF then
     CheckBoxCRLF.Checked:=true
   else
     CheckBoxCRLF.Checked:=false;


end; { procedure TForm1.FormCreate }






procedure TForm1.ConnectButtonClick(Sender: TObject);
var
  bauds: Integer;
  PortName, BaudRate : String;
begin
  if not PortConnected then begin
    PortCom := TBlockSerial.Create;
    PortCom.RaiseExcept := true;
    PortName:=ComboBoxPort.Items[ComboBoxPort.itemindex];
    PortCom.Connect(PortName);
    BaudRate:=ComboBoxBauds.Items[ComboBoxBauds.itemindex];
    bauds := StrToInt(BaudRate);
    PortCom.Config(bauds,8,'N',SB1,false,false); { baud, bits: integer; parity: char; stop: integer; softflow, hardflow: boolean }
    TimeOut := LigneMax*10000 div bauds;
    Timer1.enabled := true;
    ConnectButton.Caption:='Trennen';
    PortConnected:=true;
    Image_rt.Visible:=false;
    Image_gn.Visible:=true;
    Terminal.Lines.Add('--- Port '+PortName+' ist mit einer Baudrate von '+BaudRate+' verbunden');
  end
  else begin
    ConnectButton.Caption:='Verbinden';
    PortConnected:=false;
    Timer1.enabled := false;
    PortCom.Free;
    Image_gn.Visible:=false;
    Image_rt.Visible:=true;
    Terminal.Lines.Add('--- Port wurde getrennt');
  end;

end; { procedure TForm1.ConnectButtonClick }





procedure TForm1.SendButtonClick(Sender: TObject);
begin
  if PortConnected then begin
    if mit_CRLF then begin
      PortCom.SendString(SendString.Text+CRLF);
      Terminal.Lines.Add('<< '+SendString.Text+' CRLF');
    end
    else begin
      PortCom.SendString(SendString.Text);
      Terminal.Lines.Add('<< '+SendString.Text);
    end;

    SendString.Text:='';
  end
  else
    Terminal.Lines.Add('*** Fehler: Port ist nicht verbunden');

end; { procedure TForm1.SendButtonClick }





procedure TForm1.CheckBoxCRLFChange(Sender: TObject);
begin
  if CheckBoxCRLF.Checked then
    mit_CRLF:=true
  else
    mit_CRLF:=false;

end; { procedure TForm1.CheckBoxCRLFChange }




procedure TForm1.Timer1Timer(Sender: TObject);
var
  ReadCOM: string;
begin
  Timer1.Enabled := false;

  if PortCom.CanRead(50) = true then begin
    ReadCOM:=PortCom.RecvPacket(5);
    Terminal.Lines.Add('>> '+ReadCOM);
  end;

  Timer1.Enabled := true;

end; { procedure TForm1.Timer1Timer }




procedure TForm1.ButtonCloseClick(Sender: TObject);
begin
  Close;
end; { procedure TForm1.ButtonCloseClick }




procedure TForm1.FormDestroy(Sender: TObject);
begin
  if Assigned(FIni) then begin
    FIni.WriteString('ComPort', 'ComPort', ComboBoxPort.Items[ComboBoxPort.itemindex] );
    FIni.WriteInteger('ComPort','BaudRate', ComboBoxBauds.itemindex );
    FIni.WriteBool('ComPort','mit_CRLF', mit_CRLF );

    FIni.UpdateFile;
    FIni.Free;
  end; { if Assigned(FIni) then }

  if PortConnected then
    PortCom.Free;

end; { procedure TForm1.FormDestroy }




initialization
  {$I MainUnit.lrs}

end.

